"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DefaultMsg = void 0;
const core_1 = require("@tsed/core");
const errorMsg_1 = require("./errorMsg");
/**
 * Set default error message.
 *
 * ## Example
 *
 * ```typescript
 * @DefaultMsg("foo should be a string")
 * class Model {
 *    property: number;
 * }
 * ```
 *
 * Will produce:
 *
 * ```json
 * {
 *   "type": "object",
 *   "properties": {
 *     "property": "number"
 *   }
 *   "errorMessage": {
 *     "_": "foo should be a string"
 *   }
 * }
 * ```
 *
 * @decorator
 * @validation
 * @swagger
 * @schema
 */
function DefaultMsg(message) {
    return (0, core_1.useDecorators)((0, errorMsg_1.ErrorMsg)({ _: message }));
}
exports.DefaultMsg = DefaultMsg;
//# sourceMappingURL=defaultMsg.js.map