"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Header = void 0;
const core_1 = require("@tsed/core");
const returns_1 = require("./returns");
/**
 * Sets the response’s HTTP header field to value. To set multiple fields at once, pass an object as the parameter.
 *
 * ```typescript
 * @Header('Content-Type', 'text/plain');
 * private myMethod() {}
 *
 * @Status(204)
 * @Header({
 *   "Content-Type": "text/plain",
 *   "Content-Length": 123,
 *   "ETag": {
 *     "value": "12345",
 *     "description": "header description"
 *   }
 * })
 * private myMethod() {}
 * ```
 *
 * This example will produce the swagger responses object:
 *
 * ```json
 * {
 *   "responses": {
 *     "204": {
 *       "description": "Description",
 *       "headers": {
 *          "Content-Type": {
 *             "type": "string"
 *          },
 *          "Content-Length": {
 *             "type": "number"
 *          },
 *          "ETag": {
 *             "type": "string",
 *             "description": "header description"
 *          }
 *       }
 *     }
 *   }
 * }
 * ```
 *
 * @decorator
 * @operation
 * @response
 */
function Header(headers, value) {
    if (value !== undefined) {
        headers = { [headers]: value };
    }
    if (value === undefined && (0, core_1.isString)(headers)) {
        headers = { [headers]: { type: "string" } };
    }
    return (0, returns_1.Returns)().Headers(headers);
}
exports.Header = Header;
//# sourceMappingURL=header.js.map