/**
 * Declare a Discriminator value on a child class.
 *
 * ```ts
 * export class Event {
 *   @DiscriminatorKey() // declare this property a discriminator key
 *   type: string;
 *
 *   @Property()
 *   value: string;
 * }
 *
 * @DiscriminatorValue("page_view")
 * export class PageView extends Event {
 *   @Required()
 *   url: string;
 * }
 *
 * @DiscriminatorValue("action")
 * export class Action extends Event {
 *   @Required()
 *   event: string;
 * }
 *
 * @DiscriminatorValue()
 * export class CustomAction extends Event {
 *   @Required()
 *   event: string;
 *
 *   @Property()
 *   meta: string;
 * }
 * ```
 *
 * @decorator
 * @swagger
 * @schema
 * @classDecorator
 * @param value
 * @param values
 */
export declare function DiscriminatorValue(value?: string, ...values: string[]): ClassDecorator;
